****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: 00_master.sas  
*
* Created (mm/dd/yy): 02/14/2014
* Last modified: 02/14/2014
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*  Mini-Sentinel : 	Continuous and Group Sequential Analysis with Self-Control Design 
*										PROMPT (Prospective Routine Observational Monitoring Program Tool) 
*
*										Master program.
*										See documentation for macro and parameter details.
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Mini-Sentinel Coordinating Center
*  info@mini-sentinel.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*             mm/dd/yy
*
***************************************************************************************************;


*-----------------------------------
* Assign STANDARD Parameters
*-----------------------------------;

/* Define Data Partner and Site IDs according to table below */
%let DPID = [enter-dpid];
%let SITEID = [enter-siteid];

 /*-------------------------------------------------------------------*\
 ||                                                                   ||
 ||  DATA PARTNERS                                 DPID      SITEID   ||
 ||  -----------------------------------------------------------------||
 ||   Healthcore (one site)                         HC         OS     ||
 ||   Humana (one site)                             HU         OS     ||
 ||   Aetna (one site)                              AE         OS     ||
 ||   Optum (one site)                              OP         OS     ||
 ||   Vanderbilt University (one site)              VB         OS     ||
 ||   HMORN                                                           ||
 ||      Group Health Cooperative                   HM         GHC    ||
 ||      Fallon Community Health Plan               HM         MPCI   ||   
 ||      Henry Ford Health System                   HM         HFHS   || 
 ||      Lovelace Health System                     HM         LCF    || 
 ||      Marshfield Clinic                          HM         MCRF   ||
 ||      HealthPartners                             HM         HPRF   ||
 ||      Harvard Pilgrim Health Care                HM         HPHC   ||
 ||   Kaiser Permanente                                               ||         
 ||      Kaiser DCC                                 KP         DCC    ||
 ||      Kaiser Permanente Colorado                 KP         CO     ||
 ||      Kaiser Permanente Georgia                  KP         GA     ||
 ||      Kaiser Permanente Hawaii                   KP         HI     ||
 ||      Kaiser Permanente Northern California      KP         NC     ||
 ||      Kaiser Permanente Northwest                KP         NW     ||
 ||      Kaiser Permanente Mid Atlantic             KP         MA     ||
 \*-------------------------------------------------------------------*/
 
 
/* Define your EXPOSURE_PERIOD_CD value (to be used in conjunction with the EXPOSURE_PERIODS dataset) */
/* Alowable values are either a single number or a list of numbers separated by spaces */
/* Examples: 
		 %let exposure_period_cd=1; 
		 %let exposure_period_cd=1 2 3; 
*/
%let exposure_period_cd= [enter-exposure_period_cd]; 


/* Define MSCDM table names */
%let enrtable=enrollment;
%let demtable=demographic;
%let distable=dispensing;
%let enctable=encounter;
%let diatable=diagnosis;
%let proctable=procedure;


/* Assign paths in subsections a through d below */
/* IMPORTANT NOTE: END OF PATH SEPARATORS ARE REQUIRED!! */
/*		
			Windows-based platforms:  
				"\", e.g. "C:\user\sas\" and not "C:\user\sas";					
			Unix-based platforms:           										
				"/", e.g."/home/user/sas/" and not "/home/user/sas";	
*/

/* a. Data in MSCDM Format */		  		
libname indata "/your-path/mscdm" access=readonly;

/* b. Directory containing input files */  	
%let infolder = /your-path/inputfiles/;
libname infolder "&infolder.";

/* c. Directory to which files will be written, for sharing outside of the Data Partner */
%let msoc= /your-path/msoc/;
libname msoc "&MSOC.";

/* d. Directory to which files will be written, to be kept locally at the Data Partner */
%let dplocal= /your-path/dplocal/;
libname dplocal "&DPLocal.";



***************************************************************************************************
*******                                  END OF USER INPUT                                  *******
*******                           PLEASE DO NOT EDIT BELOW THIS LINE                        *******
***************************************************************************************************;

                                 
                                  
 DATA _NULL_;
  LENGTH exposure_period_cd $ 300;
  exposure_period_cd="&exposure_period_cd.";
   * Replace commas with blanks in case they were present in the list;
   exposure_period_cd= TRANSLATE(exposure_period_cd, " " , "," );

 * Remove multiple blanks and replace blank with _;
   exposure_period_str= TRANSLATE(TRIM(COMPBL(exposure_period_cd)), "_" , " " );

   CALL SYMPUT("exposure_period_cd", TRIM(exposure_period_cd));
   CALL SYMPUT("exposure_period_str", TRIM(exposure_period_str));
 RUN;

 %PUT exposure_period_cd=&exposure_period_cd.;
 %PUT exposure_period_str=&exposure_period_str.;

 %LET mod_prg_nm = mp410;
 %LET RequestID= scd_ep_&exposure_period_str. ;

 %PUT RequestID=&RequestID.;

%INCLUDE "&infolder.ms_episoderec.sas";
%INCLUDE "&infolder.01_mp4_10.sas";

/* If defaults are appropriate (typical case) use macro call line below */
/* For default values, see the 01_mp4_10.sas program in the /inputfiles subfolder */

%mp410(exposure_period_cd=&exposure_period_cd.);


/* If you need overwrite any of the defaults, please comment out the line above and uncomment the lines below */
/* containing the macro call */
/* See documentation for macro and parameter details */
/*
			 %mp410 (exposure_period_cd=&exposure_period_cd.,
							ENROLGAP=45,
							QUERYFROM="01JAN1970"d,
							QUERYTO="31AUG2013"d,
							QUERYFILE=query.sas7bdat,    
							INCQUERYFILE=incquery.sas7bdat,
							EVENTFILE=event.sas7bdat,
							INCEVENTFILE=incevent.sas7bdat,
							QUERY_CODES_FILE=query_codes.sas7bdat,
							EVENT_CODES_FILE=event_codes.sas7bdat,
							GROUPS_MAPPING_FILE=groups_mapping.sas7bdat,
							AGE_GROUPS_FILE=age_groups.sas7bdat,
							EXPOSURE_PERIODS_FILE=exposure_periods.sas7bdat,
							LKP_FOR_ALL_CODES_FILE=lkp_for_all_codes.sas7bdat,
							tmp=WORK,
							tmp2=WORK
							);
*/

				
				